@@ -10,14 +10,14 @@
 #ifndef KNEWSTUFF3_ENGINE_P_H
 #define KNEWSTUFF3_ENGINE_P_H
 
-#include <QObject>
-#include <QString>
-#include <QSharedPointer>
 #include <QHash>
+#include <QObject>
+#include <QSharedPointer>
+#include <QString>
 
-#include "provider.h"
 #include "entryinternal.h"
 #include "errorcode.h"
+#include "provider.h"
 
 #include "knewstuffcore_export.h"
 
@@ -106,7 +106,7 @@ public:
      *
      * @param configfile KNewStuff2 configuration file (*.knsrc)
      * @return \b true if any valid configuration was found, \b false otherwise
-    * @see KNS3::DownloadDialog
+     * @see KNS3::DownloadDialog
      */
     bool init(const QString &configfile);
 
@@ -343,11 +343,31 @@ public:
     /**
      * Convenience method to launch a search for one specific entry.
      *
-     * @note it will reset the engine state
+     * @note it will reset the engine state (use storeSearch() and restoreSearch() to handle this if needed)
      *
      * @param id The ID of the entry you wish to fetch
      */
-    void fetchEntryById(const QString &id);
+    Q_INVOKABLE void fetchEntryById(const QString &id);
+
+    /**
+     * Restore a previously saved search to be current
+     * Also emits the appropriate signals so any views depending
+     * on the information can be updated)
+     *
+     * @since 5.79
+     */
+    Q_INVOKABLE void restoreSearch();
+
+    /**
+     * Stores the current search parameters internally
+     * This might for example be used to allow you to restore the current view state
+     * after performing a single-entry fetch with fetchEntryById(QString). That function
+     * does not perform this action itself, because it may well not be the desired
+     * outcome.
+     *
+     * @since 5.79
+     */
+    Q_INVOKABLE void storeSearch();
 
     /**
      * Try to contact the author of the entry by email or showing their homepage.
@@ -619,11 +639,11 @@ Q_SIGNALS:
     void signalError(const QString &);
 #endif
 #if KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(5, 74)
-        KNEWSTUFFCORE_DEPRECATED_VERSION(5, 74, "Use Engine::busyStateChanged() and Engine::busyMessageChanged() instead")
+    KNEWSTUFFCORE_DEPRECATED_VERSION(5, 74, "Use Engine::busyStateChanged() and Engine::busyMessageChanged() instead")
     void signalBusy(const QString &);
 #endif
 #if KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(5, 74)
-        KNEWSTUFFCORE_DEPRECATED_VERSION(5, 74, "Use Engine::busyStateChanged() and Engine::busyMessageChanged() instead")
+    KNEWSTUFFCORE_DEPRECATED_VERSION(5, 74, "Use Engine::busyStateChanged() and Engine::busyMessageChanged() instead")
     void signalIdle(const QString &);
 #endif
 
@@ -631,7 +651,8 @@ Q_SIGNALS:
      * Fires in the case of any critical or serious errors, such as network or API problems.
      * @param errorCode Represents the specific type of error which has occurred
      * @param message A human-readable message which can be shown to the end user
-     * @param metadata Any additional data which might be hepful to further work out the details of the error (see KNSCore::EntryInternal::ErrorCode for the metadata details)
+     * @param metadata Any additional data which might be hepful to further work out the details of the error (see KNSCore::EntryInternal::ErrorCode for the
+     * metadata details)
      * @see KNSCore::EntryInternal::ErrorCode
      * @since 5.53
      */
@@ -639,6 +660,11 @@ Q_SIGNALS:
 
     void signalCategoriesMetadataLoded(const QList<Provider::CategoryMetadata> &categories);
 
+    /**
+     * This is fired for any event related directly to a single EntryInternal instance
+     * @see EntryInternal::EntryEvent for details on which specific event is being notified
+     * @since 5.77
+     */
     void signalEntryEvent(const EntryInternal &entry, EntryInternal::EntryEvent event);
 
 private Q_SLOTS:
@@ -682,7 +708,7 @@ private:
 
     void doRequest();
 
-    //FIXME KF6: move all of this in EnginePrivate
+    // FIXME KF6: move all of this in EnginePrivate
     // handle installation of entries
     Installation *m_installation;
     // read/write cache of entries
@@ -693,14 +719,14 @@ private:
     // Categories from knsrc file
     QStringList m_categories;
 
-    QHash<QString, QSharedPointer<KNSCore::Provider> > m_providers;
+    QHash<QString, QSharedPointer<KNSCore::Provider>> m_providers;
 
     QString m_adoptionCommand;
 
     // the current request from providers
     Provider::SearchRequest m_currentRequest;
 
-    EnginePrivate * const d;
+    EnginePrivate *const d;
 
     // the page that is currently displayed, so it is not requested repeatedly
     int m_currentPage;
